write_error_chain

Function write_error_chain 

pub fn write_error_chain(err: &dyn Error, hints: Hints<'_>) -> Result
Format an error chain and explicitly supplied hints to standard error using the default level and color.