write_error_chain_with_options

Function write_error_chain_with_options 

pub fn write_error_chain_with_options<C: DynColor + Copy, W: Write>(
    err: &dyn Error,
    options: ErrorOptions<'_, C, W>,
) -> Result
Formats an error or warning chain with custom options.

Each hint is rendered on its own line, prefixed with the styled hint: label.