Skip to main contentCrate uv_errors
Source - ErrorOptions
- Options for formatting an error chain.
- ErrorWithHints
- A display adapter for an error followed by its hints.
- HintPrefix
- A styled
hint: prefix for use in user-facing messages. - Hints
- A collection of user-facing hint messages.
- Stderr
- A standard-error writer for formatted error chains.
- Hint
- An error that may carry user-facing hints.
- write_error_chain
- Format an error chain to standard error using the default level and color.
- write_error_chain_with_options
- Formats an error or warning chain with custom options.